@@ -7,14 +7,14 @@ use strict;
 use base 'Error::Hierarchy::Internal::DBI';
 
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 # DBI exceptions store extra values, but don't use them in the message string.
 # They are marked as properties, however, so generic exception handling code
 # can introspect them.
 
-Error::Hierarchy::Internal::DBI::H->mk_accessors(qw(
+__PACKAGE__->mk_accessors(qw(
     warn active kids active_kids compat_mode inactive_destroy
     trace_level fetch_hash_key_name chop_blanks long_read_len
     long_trunc_ok taint
