@@ -6,12 +6,12 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 use base 'Error::Hierarchy::Internal';
 
-Error::Hierarchy::Internal::ReadOnlyAttribute->mk_accessors(qw(attribute));
+__PACKAGE__->mk_accessors(qw(attribute));
 
 use constant default_message => '[%s] is a read only attribute';
 
